﻿using System.Text.Json;
using PaydayFrontend.Models;

namespace PaydayFrontend.Services;

public interface IBankService
{
    public Task<List<Bank>> GetAllBanks();
    public Task<IEnumerable<Offer>> GetOffers(long directionId);
}

public class BankService : IBankService
{
    private readonly HttpClient _httpClient;

    public BankService(HttpClient httpClient)
    {
        _httpClient = httpClient;
        _httpClient.BaseAddress = new Uri("https://payday.zetcraft.ru");
    }

    public async Task<List<Bank>> GetAllBanks()
    {
        var response = await _httpClient.GetAsync("v1/admin/banks");
        var result = await response.Content.ReadAsStringAsync();
        var banks = JsonSerializer.Deserialize<List<Bank>>(result, new JsonSerializerOptions
        {
            PropertyNameCaseInsensitive = true
        });
        return banks;
    }
    
    public async Task<IEnumerable<Offer>> GetOffers(long directionId)
    {
        var response = await _httpClient.GetAsync("v1/public/credit/direction/" + directionId);
        var result = await response.Content.ReadAsStringAsync();
        var offers = JsonSerializer.Deserialize<IEnumerable<Offer>>(result, new JsonSerializerOptions
        {
            PropertyNameCaseInsensitive = true
        });
        return offers;
    }
}